@@ -126,11 +126,17 @@ class Render:
         if not self.scene.localfile.is_file():
             raise Exception("Local file does not exists")
 
+        work_path = self.scene.workdir / 'workpath'
+        work_path.mkdir(exist_ok=True)
+        working_folder = self.scene.workdir / 'working_folder'
+        working_folder.mkdir(exist_ok=True)
         max_cmd = Path(os.environ['ADSK_3DSMAX_x64_2018']) / '3dsmaxcmd'
         process = Popen([
             str(max_cmd),
             "-continueOnError",
             "-batchRender",
+            f"-workPath:{str(work_path)}"
+            f"-workingFolder:{str(working_folder)}"
             f'-outputName:{str(self.scene.workdir / f"0.{extension}")}',
             str(self.scene.localfile)],
             stderr=STDOUT,
