@@ -1,30 +1,30 @@
 import logging
-import os
 import sys
-import time
-from functools import partial
-from multiprocessing import Process
+from time import sleep
 
 import pyscreenshot as ImageGrab
-
 import wx
+from mss import mss
+
 from render import RENDER_DIR
 
 logger = logging.getLogger(__name__)
 
 
-def capture_screenshots(delay):
+def capture_screenshots(tick):
     logger.debug("Screenshots configuring...")
     path = RENDER_DIR / 'screens'
     path.mkdir(exist_ok=True)
-    wx.App()  # Need to create an App instance before doing anything
+    with mss() as sct:
+        sct.shot(mon=-1, output=str(path / f'mss-{tick}.png'))
 
-    wx_filename = path / f'wx-screen.png'
-    grab_filename = path / f'grab-screen.png'
+    grab_filename = path / f'grab-screen-{tick}.png'
 
     im = ImageGrab.grab()
     im.save(str(grab_filename))
 
+    wx_filename = path / f'wx-screen-{tick}.png'
+    wx.App()  # Need to create an App instance before doing anything
     screen = wx.ScreenDC()
     size = screen.GetSize()
     bmp = wx.EmptyBitmap(size[0], size[1])
@@ -33,24 +33,21 @@ def capture_screenshots(delay):
     del mem  # Release bitmap
     bmp.SaveFile(str(wx_filename), wx.BITMAP_TYPE_PNG)
 
+    # with Display(size=(100, 60)) as disp:  # start Xvfb display
+    #     # display is available
+    #     with EasyProcess(["xmessage", "hello"]):  # start xmessage
+    #         sleep(1)  # wait for diplaying window
+    #         img = ImageGrab.grab()
+    # img.save("xmessage.png")
 
-    from time import sleep
-
-    from easyprocess import EasyProcess
-    from pyvirtualdisplay import Display
-
-    import pyscreenshot as ImageGrab
-
-    with Display(size=(100, 60)) as disp:  # start Xvfb display
-        # display is available
-        with EasyProcess(["xmessage", "hello"]):  # start xmessage
-            sleep(1)  # wait for diplaying window
-            img = ImageGrab.grab()
-    img.save("xmessage.png")
 
 def main():
     delay = int(sys.argv[1])
-    capture_screenshots(delay)
+    tick = 0
+    while True:
+        capture_screenshots(tick)
+        sleep(delay)
+        tick += 1
 
 
 if __name__ == '__main__':
